==> haskell-interpolate-0.2.0-39-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-interpolate.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: interpolate
version: 0.2.0
id: interpolate-0.2.0-LwI6PCFq38B5qeuW118VEa
key: interpolate-0.2.0-LwI6PCFq38B5qeuW118VEa
license: MIT
copyright: (c) 2013-2015 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: https://github.com/sol/interpolate#readme
synopsis: String interpolation done right
description:
    String interpolation done right
category: Data, Text
abi: 261fa674d0b5d09cc7cfa5b5f8f1dc9e
exposed: True
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.IsString
    Data.String.Interpolate.Util
hidden-modules: Data.String.Interpolate.Compat
                Data.String.Interpolate.Internal.Util Data.String.Interpolate.Parse
                Paths_interpolate
import-dirs: /usr/lib/ghc-8.4.3/site-local/interpolate-0.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/interpolate-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/interpolate-0.2.0
hs-libraries: HSinterpolate-0.2.0-LwI6PCFq38B5qeuW118VEa
depends:
    base-4.11.1.0 haskell-src-meta-0.8.0.3-3LDPqE81yMjJNNCF1e8ZDo
    template-haskell-2.13.0.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             haskell-src-meta-0.8.0.3-3LDPqE81yMjJNNCF1e8ZDo=183db6675f5e0266ea9b13be8febe171
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
haddock-interfaces: /usr/share/doc/haskell-interpolate/html/interpolate.haddock
haddock-html: /usr/share/doc/haskell-interpolate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-interpolate-0.2.0-40-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-interpolate.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: interpolate
version: 0.2.0
id: interpolate-0.2.0-6ER2kwTe2QmJomftMtKNTE
key: interpolate-0.2.0-6ER2kwTe2QmJomftMtKNTE
license: MIT
copyright: (c) 2013-2015 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: https://github.com/sol/interpolate#readme
synopsis: String interpolation done right
description:
    String interpolation done right
category: Data, Text
abi: 4240856ad56537a2531ee6e022969c25
exposed: True
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.IsString
    Data.String.Interpolate.Util
hidden-modules: Data.String.Interpolate.Compat
                Data.String.Interpolate.Internal.Util Data.String.Interpolate.Parse
                Paths_interpolate
import-dirs: /usr/lib/ghc-8.4.3/site-local/interpolate-0.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/interpolate-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/interpolate-0.2.0
hs-libraries: HSinterpolate-0.2.0-6ER2kwTe2QmJomftMtKNTE
depends:
    base-4.11.1.0 haskell-src-meta-0.8.0.3-HwMp7B5kMNQGcpqxYLNyJ2
    template-haskell-2.13.0.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             haskell-src-meta-0.8.0.3-HwMp7B5kMNQGcpqxYLNyJ2=7fe0e668d2ed958edb52a7dde8d7d38f
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
haddock-interfaces: /usr/share/doc/haskell-interpolate/html/interpolate.haddock
haddock-html: /usr/share/doc/haskell-interpolate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
